@@ -121,7 +121,7 @@ class HttpService(object):
         if 'application/json' in content_type or 'text/json' in content_type:
             # JSON 类型
             data = covert_dict_key_to_lower(d=response.json())
-        elif 'text/plain' in content_type:
+        elif 'text/plain' in content_type or 'text/html' in content_type:
             # 纯文本类型
             data = dict(code=response.status_code, message=get_html_title(
                 html=response.text), data=response.text)
